@@ -90,30 +90,34 @@ else
     end
 end
 % VARIANCE DECOMPOSITION.
-if posterior
-    for i=1:NumberOfEndogenousVariables
-        for j=1:NumberOfExogenousVariables
-            oo_ = posterior_analysis('decomposition',var_list_(i,:),M_.exo_names(j,:),[],options_,M_,oo_);
+if M_.exo_nbr > 1
+    if posterior
+        for i=1:NumberOfEndogenousVariables
+            for j=1:NumberOfExogenousVariables
+                oo_ = posterior_analysis('decomposition',var_list_(i,:),M_.exo_names(j,:),[],options_,M_,oo_);
+            end
+        end
+    else
+        for i=1:NumberOfEndogenousVariables
+            for j=1:NumberOfExogenousVariables
+                oo_ = prior_analysis('decomposition',var_list_(i,:),M_.exo_names(j,:),[],options_,M_,oo_);
+            end
+        end        
+    end
+    % CONDITIONAL VARIANCE DECOMPOSITION.
+    if Steps
+        if posterior
+            for i=1:NumberOfEndogenousVariables
+                for j=1:NumberOfExogenousVariables
+                    oo_ = posterior_analysis('conditional decomposition',var_list_(i,:),M_.exo_names(j,:),Steps,options_,M_,oo_);
+                end
+            end
+        else
+            for i=1:NumberOfEndogenousVariables
+                for j=1:NumberOfExogenousVariables
+                    oo_ = prior_analysis('conditional decomposition',var_list_(i,:),M_.exo_names(j,:),Steps,options_,M_,oo_);
+                end
+            end
         end
     end
-else
-    for i=1:NumberOfEndogenousVariables
-        for j=1:NumberOfExogenousVariables
-            oo_ = prior_analysis('decomposition',var_list_(i,:),M_.exo_names(j,:),[],options_,M_,oo_);
-        end
-    end        
 end
-% CONDITIONAL VARIANCE DECOMPOSITION.
-if posterior
-    for i=1:NumberOfEndogenousVariables
-        for j=1:NumberOfExogenousVariables
-            oo_ = posterior_analysis('conditional decomposition',var_list_(i,:),M_.exo_names(j,:),Steps,options_,M_,oo_);
-        end
-    end
-else
-    for i=1:NumberOfEndogenousVariables
-        for j=1:NumberOfExogenousVariables
-            oo_ = prior_analysis('conditional decomposition',var_list_(i,:),M_.exo_names(j,:),Steps,options_,M_,oo_);
-        end
-    end
-end
\ No newline at end of file
