@@ -51,6 +51,10 @@ function [dr,info,M_,options_,oo_] = dr1(dr,task,M_,options_,oo_)
 
 info = 0;
 
+if M_.maximum_endo_lag == 0 && options_.order > 1
+    error(['2nd and 3rd order approximation not implemented for purely forward models'])
+end
+
 if options_.k_order_solver;
     dr = set_state_space(dr,M_);
     [dr,info] = k_order_pert(dr,M_,options_,oo_);
@@ -217,8 +221,9 @@ if M_.maximum_endo_lead == 0
         end
     else % use original Dynare solver
         [k1,junk,k2] = find(kstate(:,4));
-        dr.ghx(:,k1) = -b\jacobia_(:,k2); 
-        if M_.exo_nbr
+        dr.ghx(:,k1) = -b\jacobia_(:,k2);
+        % with simul, the Jacobian doesn't contain derivatives w.r. to shocks
+        if size(jacobia_,2) > nz
             dr.ghu = -b\jacobia_(:,nz+1:end);
         end
     end % if not use AIM or not...
@@ -347,16 +352,27 @@ else  % use original Dynare solver
     end
 
     if nba ~= nyf
-        temp = sort(abs(dr.eigval));
-        if nba > nyf
-            temp = temp(nd-nba+1:nd-nyf)-1-options_.qz_criterium;
-            info(1) = 3;
-        elseif nba < nyf;
-            temp = temp(nd-nyf+1:nd-nba)-1-options_.qz_criterium;
-            info(1) = 4;
+        sorted_roots = sort(abs(dr.eigval));
+        if isfield(options_,'indeterminacy_continuity')
+            if options_.indeterminacy_msv == 1
+                [ss,tt,w,q] = qz(e',d');
+                [ss,tt,w,q] = reorder(ss,tt,w,q);
+                ss = ss';
+                tt = tt';
+                w  = w';
+                nba = nyf;
+            end
+        else
+            if nba > nyf
+                temp = sorted_roots(nd-nba+1:nd-nyf)-1-options_.qz_criterium;
+                info(1) = 3;
+            elseif nba < nyf;
+                temp = sorted_roots(nd-nyf+1:nd-nba)-1-options_.qz_criterium;
+                info(1) = 4;
+            end
+            info(2) = temp'*temp;
+            return
         end
-        info(2) = temp'*temp;
-        return
     end
 
     np = nd - nyf;
@@ -366,7 +382,8 @@ else  % use original Dynare solver
     % derivatives with respect to dynamic state variables
     % forward variables
     w1 =w(1:n3,n2:nd);
-    if condest(w1) > 1e9;
+    if ~isfloat(w1) && (condest(w1) > 1e9)
+        % condest() fails on a scalar under Octave
         info(1) = 5;
         info(2) = condest(w1);
         return;
