@@ -17,7 +17,7 @@ function y = irf(dr, e1, long, drop, replic, iorder)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2003-2008 Dynare Team
+% Copyright (C) 2003-2010 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -37,7 +37,11 @@ function y = irf(dr, e1, long, drop, replic, iorder)
 global M_ oo_ options_
 
 
-temps = repmat(dr.ys,1,M_.maximum_lag);
+if M_.maximum_lag >= 1
+    temps = repmat(dr.ys,1,M_.maximum_lag);
+else
+    temps = zeros(M_.endo_nbr, 1); % Dummy values for purely forward models
+end
 y       = 0;
 
 if iorder == 1
