@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2009 Dynare Team
+ * Copyright (C) 2003-2010 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -320,12 +320,20 @@ EstimatedParamsStatement::EstimatedParamsStatement(const vector<EstimationParams
 {
   for (vector<EstimationParams>::const_iterator it = estim_params_list.begin();
        it != estim_params_list.end(); it++)
+    // Handle case of degenerate beta prior
     if (it->prior == "1") //BETA_PDF is associated with "1" in DynareBison.yy
-      if (dynamic_cast<NumConstNode *>(it->mean)->isNumConstNodeEqualTo(0.5) &&
-          dynamic_cast<NumConstNode *>(it->std)->isNumConstNodeEqualTo(0.5))
+      try
         {
-          cerr << "The prior density is not defined for the beta distribution when the mean = standard deviation = 0.5." << endl;
-          exit(EXIT_FAILURE);
+          if (it->mean->eval(eval_context_type()) == 0.5 &&
+              it->std->eval(eval_context_type()) == 0.5)
+            {
+              cerr << "ERROR: The prior density is not defined for the beta distribution when the mean = standard deviation = 0.5." << endl;
+              exit(EXIT_FAILURE);
+            }
+        }
+      catch (ExprNode::EvalException &e)
+        {
+          // We don't have enough information to compute the numerical value, skip the test
         }
 }
 
@@ -779,7 +787,7 @@ OptimWeightsStatement::writeOutput(ostream &output, const string &basename) cons
       output <<  "optim_weights_(" << id1 << "," << id2 << ") = ";
       value->writeOutput(output);
       output << ";" << endl;
-      output << "obj_var_ = [obj_var_; " << id1 << " " << id2 << "];\n";
+      output << "obj_var_ = [obj_var_; " << id1 << "; " << id2 << "];\n";
     }
 }
 
@@ -979,17 +987,14 @@ WriteLatexStaticModelStatement::writeOutput(ostream &output, const string &basen
   static_model.writeLatexFile(basename);
 }
 
-ShockDecompositionStatement::ShockDecompositionStatement(const SymbolList &symbol_list_arg,
-                                                         const OptionsList &options_list_arg) :
-  symbol_list(symbol_list_arg),
-  options_list(options_list_arg)
+ShockDecompositionStatement::ShockDecompositionStatement(const SymbolList &symbol_list_arg) :
+  symbol_list(symbol_list_arg)
 {
 }
 
 void
 ShockDecompositionStatement::writeOutput(ostream &output, const string &basename) const
 {
-  options_list.writeOutput(output);
   symbol_list.writeOutput("var_list_", output);
   output << "oo_ = shock_decomposition(M_,oo_,options_,var_list_);\n";
 }
