@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2009 Dynare Team
+ * Copyright (C) 2003-2010 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -213,6 +213,9 @@ ParsingDriver::add_model_variable(string *name, string *olag)
   if (type == eModelLocalVariable && lag != 0)
     error("Model local variable " + *name + " cannot be given a lead or a lag.");
 
+  if (dynamic_cast<StaticModel *>(model_tree) != NULL && lag != 0)
+    error("Leads and lags on variables are forbidden in 'planner_objective'.");
+
   // It makes sense to allow a lead/lag on parameters: during steady state calibration, endogenous and parameters can be swapped
 
   NodeID id = model_tree->AddVariable(*name, lag);
@@ -1291,9 +1294,8 @@ ParsingDriver::markov_switching()
 void
 ParsingDriver::shock_decomposition()
 {
-  mod_file->addStatement(new ShockDecompositionStatement(symbol_list, options_list));
+  mod_file->addStatement(new ShockDecompositionStatement(symbol_list));
   symbol_list.clear();
-  options_list.clear();
 }
 
 void
