@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2009 Dynare Team
+ * Copyright (C) 2003-2010 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -343,6 +343,15 @@ SymbolTable::addExpectationAuxiliaryVar(int information_set, int index) throw (F
   return symb_id;
 }
 
+int 
+SymbolTable::searchAuxiliaryVars(int orig_symb_id, int orig_lead_lag) const
+{
+  for (int i=0; i < aux_vars.size();++i)
+    if ((aux_vars[i].orig_symb_id == orig_symb_id) && (aux_vars[i].orig_lead_lag == orig_lead_lag))
+      return aux_vars[i].symb_id;
+  return -1;
+}
+
 void
 SymbolTable::markPredetermined(int symb_id) throw (UnknownSymbolIDException, FrozenException)
 {
